q1ss.binalg.binmat
==================

.. automodule:: q1ss.binalg.binmat

MatBitIdx
---------

.. autodata:: q1ss.binalg.binmat.MatBitIdx

MatSubmatIdx
------------

.. autodata:: q1ss.binalg.binmat.MatSubmatIdx

MatSubvecIdx
------------

.. autodata:: q1ss.binalg.binmat.MatSubvecIdx

binmat
------

.. autoclass:: q1ss.binalg.binmat.binmat
    :show-inheritance:
    :members:
    :special-members: __invert__, __neg__, __pos__, __add__, __mul__, __matmul__, __or__, __sub__, __iadd__, __imul__, __imatmul__, __isub__, __new__, __getitem__
